==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/speech/translations/speech_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Řeč</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Oznámení</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Největší počet písmen, která se mají říct</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Zpráva je příliš dlouhá (muž)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Zpráva je příliš dlouhá (žena)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Hlas</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekvence</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Základní frekvence</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Zvukový systém</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Zařízení Dsp</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt (potřebuje dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Program Speech</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Zkouška</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Mužský hlas</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Ženský hlas</translation>
    </message>
</context>
</TS>

==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/speech/translations/speech_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Řeč</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Oznámení</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Největší počet písmen, která se mají říct</translation>
    </message>
    <message>
        <source>Message too long (male)</source>
        <translation>Zpráva je příliš dlouhá (muž)</translation>
    </message>
    <message>
        <source>Message too long (female)</source>
        <translation>Zpráva je příliš dlouhá (žena)</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Hlas</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frekvence</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Základní frekvence</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Melodie</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation>Zvukový systém</translation>
    </message>
    <message>
        <source>aRts</source>
        <translation>aRts</translation>
    </message>
    <message>
        <source>Esd</source>
        <translation>Esd</translation>
    </message>
    <message>
        <source>Dsp</source>
        <translation>Dsp</translation>
    </message>
    <message>
        <source>Dsp device</source>
        <translation>Zařízení Dsp</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt (potřebuje dsp)</translation>
    </message>
    <message>
        <source>Speech program</source>
        <translation>Program Speech</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Zkouška</translation>
    </message>
    <message>
        <source>Read a text</source>
        <translation>Číst text</translation>
    </message>
</context>
<context>
    <name>SpeechConfigurationWidget</name>
    <message>
        <source>Male format</source>
        <translation>Mužský hlas</translation>
    </message>
    <message>
        <source>Female format</source>
        <translation>Ženský hlas</translation>
    </message>
</context>
</TS>
